==> NiaAML-1.1.0.tar.gz: NiaAML-1.1.0/CHANGELOG.md <==
# Changelog

## [1.0.0rc7](https://github.com/lukapecnik/niaaml/tree/1.0.0rc7) (2020-12-14)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc6...1.0.0rc7)

**Closed issues:**

- References [\#40](https://github.com/lukapecnik/NiaAML/issues/40)

**Merged pull requests:**

- Paper update [\#42](https://github.com/lukapecnik/NiaAML/pull/42) ([firefly-cpp](https://github.com/firefly-cpp))
- minor corrections in examples [\#39](https://github.com/lukapecnik/NiaAML/pull/39) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc6](https://github.com/lukapecnik/niaaml/tree/1.0.0rc6) (2020-12-12)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc5...1.0.0rc6)

**Closed issues:**

- Conda package [\#34](https://github.com/lukapecnik/NiaAML/issues/34)

**Merged pull requests:**

- Additional features [\#38](https://github.com/lukapecnik/NiaAML/pull/38) ([lukapecnik](https://github.com/lukapecnik))
- Conda fix \[ci skip\] [\#37](https://github.com/lukapecnik/NiaAML/pull/37) ([lukapecnik](https://github.com/lukapecnik))
- Orcid identifiers added [\#36](https://github.com/lukapecnik/NiaAML/pull/36) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc5](https://github.com/lukapecnik/niaaml/tree/1.0.0rc5) (2020-12-11)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc4...1.0.0rc5)

**Closed issues:**

- Installation problems [\#31](https://github.com/lukapecnik/NiaAML/issues/31)

**Merged pull requests:**

- Conda support [\#35](https://github.com/lukapecnik/NiaAML/pull/35) ([lukapecnik](https://github.com/lukapecnik))

## [1.0.0rc4](https://github.com/lukapecnik/niaaml/tree/1.0.0rc4) (2020-12-10)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc3...1.0.0rc4)

**Merged pull requests:**

- Python 3.6 support [\#33](https://github.com/lukapecnik/NiaAML/pull/33) ([lukapecnik](https://github.com/lukapecnik))
- First version of paper [\#32](https://github.com/lukapecnik/NiaAML/pull/32) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc3](https://github.com/lukapecnik/niaaml/tree/1.0.0rc3) (2020-12-10)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc2...1.0.0rc3)

## [1.0.0rc2](https://github.com/lukapecnik/niaaml/tree/1.0.0rc2) (2020-12-08)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc1...1.0.0rc2)

**Merged pull requests:**

- feature missing values imputation [\#30](https://github.com/lukapecnik/NiaAML/pull/30) ([lukapecnik](https://github.com/lukapecnik))
- README updated [\#29](https://github.com/lukapecnik/NiaAML/pull/29) ([firefly-cpp](https://github.com/firefly-cpp))
- Readme update, encoder check for type int64 [\#28](https://github.com/lukapecnik/NiaAML/pull/28) ([lukapecnik](https://github.com/lukapecnik))
- Markdown and docs [\#27](https://github.com/lukapecnik/NiaAML/pull/27) ([lukapecnik](https://github.com/lukapecnik))

## [1.0.0rc1](https://github.com/lukapecnik/niaaml/tree/1.0.0rc1) (2020-12-06)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.4...1.0.0rc1)

**Merged pull requests:**

- Added support for categorical features [\#26](https://github.com/lukapecnik/NiaAML/pull/26) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.4](https://github.com/lukapecnik/niaaml/tree/0.1.4) (2020-12-05)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.3...0.1.4)

**Merged pull requests:**

- remove 10-fold cross validation from benchmark, critical bug fix [\#25](https://github.com/lukapecnik/NiaAML/pull/25) ([lukapecnik](https://github.com/lukapecnik))
- run all experiments at once [\#24](https://github.com/lukapecnik/NiaAML/pull/24) ([firefly-cpp](https://github.com/firefly-cpp))

## [0.1.3](https://github.com/lukapecnik/niaaml/tree/0.1.3) (2020-12-04)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.3a1...0.1.3)

## [0.1.3a1](https://github.com/lukapecnik/niaaml/tree/0.1.3a1) (2020-12-01)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.2...0.1.3a1)

**Merged pull requests:**

- 0.1.3a1 pre-release python 3.7 compatibility [\#23](https://github.com/lukapecnik/NiaAML/pull/23) ([lukapecnik](https://github.com/lukapecnik))
- Fixes and additions [\#22](https://github.com/lukapecnik/NiaAML/pull/22) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.2](https://github.com/lukapecnik/niaaml/tree/0.1.2) (2020-11-30)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.2a1...0.1.2)

**Implemented enhancements:**

- On the use of unittest [\#2](https://github.com/lukapecnik/NiaAML/issues/2)

**Closed issues:**

- Description of examples [\#16](https://github.com/lukapecnik/NiaAML/issues/16)

**Merged pull requests:**

- readme.rst fix, pipeline fix [\#21](https://github.com/lukapecnik/NiaAML/pull/21) ([lukapecnik](https://github.com/lukapecnik))
- Travis ci integration [\#20](https://github.com/lukapecnik/NiaAML/pull/20) ([lukapecnik](https://github.com/lukapecnik))
- badges and readme update [\#19](https://github.com/lukapecnik/NiaAML/pull/19) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.2a1](https://github.com/lukapecnik/niaaml/tree/0.1.2a1) (2020-11-29)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.1...0.1.2a1)

**Closed issues:**

- Information about hyperparameter tuning [\#15](https://github.com/lukapecnik/NiaAML/issues/15)
- CHANGELOG [\#14](https://github.com/lukapecnik/NiaAML/issues/14)
- Examples [\#13](https://github.com/lukapecnik/NiaAML/issues/13)

**Merged pull requests:**

- Unittests, examples' description, references added to docs [\#17](https://github.com/lukapecnik/NiaAML/pull/17) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.1](https://github.com/lukapecnik/niaaml/tree/0.1.1) (2020-11-28)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.0...0.1.1)

**Closed issues:**

- Installation instructions [\#11](https://github.com/lukapecnik/NiaAML/issues/11)

**Merged pull requests:**

- Contributors table added [\#12](https://github.com/lukapecnik/NiaAML/pull/12) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.0](https://github.com/lukapecnik/niaaml/tree/0.1.0) (2020-11-27)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/fbf47d71adb6ba72aa9210e4ead316b318253862...0.1.0)

**Implemented enhancements:**

- CSV Data Reader class [\#3](https://github.com/lukapecnik/NiaAML/issues/3)

**Closed issues:**

- A non-functional demo could be written [\#4](https://github.com/lukapecnik/NiaAML/issues/4)

**Merged pull requests:**

- Framework improvements, docs initialization and readme [\#10](https://github.com/lukapecnik/NiaAML/pull/10) ([lukapecnik](https://github.com/lukapecnik))
- Pipeline methods implementation [\#9](https://github.com/lukapecnik/NiaAML/pull/9) ([lukapecnik](https://github.com/lukapecnik))
- Pipeline optimizer progress [\#8](https://github.com/lukapecnik/NiaAML/pull/8) ([lukapecnik](https://github.com/lukapecnik))
- Implementation of jDEFSTH algorithm for feature selection [\#7](https://github.com/lukapecnik/NiaAML/pull/7) ([firefly-cpp](https://github.com/firefly-cpp))
- refactoring and variance threshold feature selection implementation [\#6](https://github.com/lukapecnik/NiaAML/pull/6) ([lukapecnik](https://github.com/lukapecnik))
- NiaPy dependency added [\#5](https://github.com/lukapecnik/NiaAML/pull/5) ([firefly-cpp](https://github.com/firefly-cpp))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> NiaAML-1.1.1rc2.tar.gz: NiaAML-1.1.1rc2/CHANGELOG.md <==
# Changelog

## [1.1.1rc2](https://github.com/lukapecnik/niaaml/tree/1.1.1rc2) (2020-12-22)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.1rc1...1.1.1rc2)

## [1.1.1rc1](https://github.com/lukapecnik/niaaml/tree/1.1.1rc1) (2020-12-22)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.0...1.1.1rc1)

**Merged pull requests:**

- Original NiaAML method support \[ci skip\] [\#43](https://github.com/lukapecnik/NiaAML/pull/43) ([lukapecnik](https://github.com/lukapecnik))

## [1.1.0](https://github.com/lukapecnik/niaaml/tree/1.1.0) (2020-12-16)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc7...1.1.0)

## [1.0.0rc7](https://github.com/lukapecnik/niaaml/tree/1.0.0rc7) (2020-12-14)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc6...1.0.0rc7)

**Closed issues:**

- References [\#40](https://github.com/lukapecnik/NiaAML/issues/40)

**Merged pull requests:**

- Paper update [\#42](https://github.com/lukapecnik/NiaAML/pull/42) ([firefly-cpp](https://github.com/firefly-cpp))
- minor corrections in examples [\#39](https://github.com/lukapecnik/NiaAML/pull/39) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc6](https://github.com/lukapecnik/niaaml/tree/1.0.0rc6) (2020-12-12)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc5...1.0.0rc6)

**Closed issues:**

- Conda package [\#34](https://github.com/lukapecnik/NiaAML/issues/34)

**Merged pull requests:**

- Additional features [\#38](https://github.com/lukapecnik/NiaAML/pull/38) ([lukapecnik](https://github.com/lukapecnik))
- Conda fix \[ci skip\] [\#37](https://github.com/lukapecnik/NiaAML/pull/37) ([lukapecnik](https://github.com/lukapecnik))
- Orcid identifiers added [\#36](https://github.com/lukapecnik/NiaAML/pull/36) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc5](https://github.com/lukapecnik/niaaml/tree/1.0.0rc5) (2020-12-11)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc4...1.0.0rc5)

**Closed issues:**

- Installation problems [\#31](https://github.com/lukapecnik/NiaAML/issues/31)

**Merged pull requests:**

- Conda support [\#35](https://github.com/lukapecnik/NiaAML/pull/35) ([lukapecnik](https://github.com/lukapecnik))

## [1.0.0rc4](https://github.com/lukapecnik/niaaml/tree/1.0.0rc4) (2020-12-10)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc3...1.0.0rc4)

**Merged pull requests:**

- Python 3.6 support [\#33](https://github.com/lukapecnik/NiaAML/pull/33) ([lukapecnik](https://github.com/lukapecnik))
- First version of paper [\#32](https://github.com/lukapecnik/NiaAML/pull/32) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc3](https://github.com/lukapecnik/niaaml/tree/1.0.0rc3) (2020-12-10)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc2...1.0.0rc3)

## [1.0.0rc2](https://github.com/lukapecnik/niaaml/tree/1.0.0rc2) (2020-12-08)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc1...1.0.0rc2)

**Merged pull requests:**

- feature missing values imputation [\#30](https://github.com/lukapecnik/NiaAML/pull/30) ([lukapecnik](https://github.com/lukapecnik))
- README updated [\#29](https://github.com/lukapecnik/NiaAML/pull/29) ([firefly-cpp](https://github.com/firefly-cpp))
- Readme update, encoder check for type int64 [\#28](https://github.com/lukapecnik/NiaAML/pull/28) ([lukapecnik](https://github.com/lukapecnik))
- Markdown and docs [\#27](https://github.com/lukapecnik/NiaAML/pull/27) ([lukapecnik](https://github.com/lukapecnik))

## [1.0.0rc1](https://github.com/lukapecnik/niaaml/tree/1.0.0rc1) (2020-12-06)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.4...1.0.0rc1)

**Merged pull requests:**

- Added support for categorical features [\#26](https://github.com/lukapecnik/NiaAML/pull/26) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.4](https://github.com/lukapecnik/niaaml/tree/0.1.4) (2020-12-05)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.3...0.1.4)

**Merged pull requests:**

- remove 10-fold cross validation from benchmark, critical bug fix [\#25](https://github.com/lukapecnik/NiaAML/pull/25) ([lukapecnik](https://github.com/lukapecnik))
- run all experiments at once [\#24](https://github.com/lukapecnik/NiaAML/pull/24) ([firefly-cpp](https://github.com/firefly-cpp))

## [0.1.3](https://github.com/lukapecnik/niaaml/tree/0.1.3) (2020-12-04)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.3a1...0.1.3)

## [0.1.3a1](https://github.com/lukapecnik/niaaml/tree/0.1.3a1) (2020-12-01)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.2...0.1.3a1)

**Merged pull requests:**

- 0.1.3a1 pre-release python 3.7 compatibility [\#23](https://github.com/lukapecnik/NiaAML/pull/23) ([lukapecnik](https://github.com/lukapecnik))
- Fixes and additions [\#22](https://github.com/lukapecnik/NiaAML/pull/22) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.2](https://github.com/lukapecnik/niaaml/tree/0.1.2) (2020-11-30)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.2a1...0.1.2)

**Implemented enhancements:**

- On the use of unittest [\#2](https://github.com/lukapecnik/NiaAML/issues/2)

**Closed issues:**

- Description of examples [\#16](https://github.com/lukapecnik/NiaAML/issues/16)

**Merged pull requests:**

- readme.rst fix, pipeline fix [\#21](https://github.com/lukapecnik/NiaAML/pull/21) ([lukapecnik](https://github.com/lukapecnik))
- Travis ci integration [\#20](https://github.com/lukapecnik/NiaAML/pull/20) ([lukapecnik](https://github.com/lukapecnik))
- badges and readme update [\#19](https://github.com/lukapecnik/NiaAML/pull/19) ([lukapecnik](https://github.com/lukapecnik))
- Pipeline optimizer progress [\#8](https://github.com/lukapecnik/NiaAML/pull/8) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.2a1](https://github.com/lukapecnik/niaaml/tree/0.1.2a1) (2020-11-29)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.1...0.1.2a1)

**Closed issues:**

- Information about hyperparameter tuning [\#15](https://github.com/lukapecnik/NiaAML/issues/15)
- CHANGELOG [\#14](https://github.com/lukapecnik/NiaAML/issues/14)
- Examples [\#13](https://github.com/lukapecnik/NiaAML/issues/13)

**Merged pull requests:**

- Unittests, examples' description, references added to docs [\#17](https://github.com/lukapecnik/NiaAML/pull/17) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.1](https://github.com/lukapecnik/niaaml/tree/0.1.1) (2020-11-28)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.0...0.1.1)

**Closed issues:**

- Installation instructions [\#11](https://github.com/lukapecnik/NiaAML/issues/11)

**Merged pull requests:**

- Contributors table added [\#12](https://github.com/lukapecnik/NiaAML/pull/12) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.0](https://github.com/lukapecnik/niaaml/tree/0.1.0) (2020-11-27)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/fbf47d71adb6ba72aa9210e4ead316b318253862...0.1.0)

**Implemented enhancements:**

- CSV Data Reader class [\#3](https://github.com/lukapecnik/NiaAML/issues/3)

**Closed issues:**

- A non-functional demo could be written [\#4](https://github.com/lukapecnik/NiaAML/issues/4)

**Merged pull requests:**

- Framework improvements, docs initialization and readme [\#10](https://github.com/lukapecnik/NiaAML/pull/10) ([lukapecnik](https://github.com/lukapecnik))
- Pipeline methods implementation [\#9](https://github.com/lukapecnik/NiaAML/pull/9) ([lukapecnik](https://github.com/lukapecnik))
- Implementation of jDEFSTH algorithm for feature selection [\#7](https://github.com/lukapecnik/NiaAML/pull/7) ([firefly-cpp](https://github.com/firefly-cpp))
- refactoring and variance threshold feature selection implementation [\#6](https://github.com/lukapecnik/NiaAML/pull/6) ([lukapecnik](https://github.com/lukapecnik))
- NiaPy dependency added [\#5](https://github.com/lukapecnik/NiaAML/pull/5) ([firefly-cpp](https://github.com/firefly-cpp))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
